/*
Rabih Kaddour
Copyright 2016! Inc. All rights reserved.
Licensed under the BSD License.
http://kaddour-es.de
*/

////////////////////////////
////// HELPERS
////////////////////////////
var renderer = null;
var scene = null;
var camera = null;
var canvas = null;
var fov = 75;
var near = 0.1;
var far = 2000;

function init() {
  // Get the document with Id
  var elmtDiv = document.getElementById('WebGLCanvas');
  if(elmtDiv) {
    canvas = elmtDiv;
    canvas.height = elmtDiv.clientHeight;
    canvas.width = elmtDiv.clientWidth;
  }
  else {
    canvas = document.getElementById('WebGLCanvas');
    canvas.width = window.innerWidth;
    canvas.height = window.innerHeight;
  }

  // Create a camera
  // Set a Field of View (FOV) of 75 degrees
  // Set an Apsect Ratio of the inner width divided by the inner height of the window
  // Set the 'Near' distance at which the camera will start rendering scene objects to 2
  // Set the 'Far' (draw distance) at which objects will not be rendered to 1000
  camera = new THREE.PerspectiveCamera(fov, canvas.width / canvas.height, near, far);

  // Set the camera position so that it's up top and looking down:
  var posX=200, posY=200, posZ=350;
  camera.position.z = posZ;

  // Create main scene
  // This is the scene we will add all objects to.
  // Create a scene, that will hold all our elements such as objects, cameras and lights.
  scene = new THREE.Scene();

  // White directional light at half intensity shining from the top.
  var directionalLight = new THREE.DirectionalLight( 0xffffff, 1 );
  scene.add( directionalLight );

  // Add the camera to the scene
  scene.add(camera);

  // create a line
  createLine();

  // create a spline
  createSplineCurve()

  // Create a WebGL Rendered
  renderer = new THREE.WebGLRenderer();

  // Set the size of the rendered to the inner width and inner height of the window
  renderer.setPixelRatio( window.devicePixelRatio );
  renderer.setSize(canvas.width, canvas.height);

  // Background
  renderer.setClearColor(0xdddddd); // gray

  // Add in the created DOM element to the body of the document
  canvas.appendChild(renderer.domElement);

  // callback rendering
  // render();
  requestAnimationFrame(render);

  // Register an event listener to
  // call the resizeCanvas() function each time
  // the window is resized.
  window.addEventListener('resize', resizeRendererToDisplaySize, false);
}

// var material = new THREE.MeshLambertMaterial({color: 0xff3300});

var _curve = null;
// Create a line
function createLine() {

  var points = [];
  points.push ( new THREE.Vector3 (-70, 0, 0) );
  points.push ( new THREE.Vector3 (0, 70, 0) );
  points.push ( new THREE.Vector3 (70, 0, 0) );
  var geometry = new THREE.BufferGeometry ().setFromPoints( points );

  // Create a blue LineBasicMaterial
  var material = new THREE.LineBasicMaterial ({ color: 0xff0000 });

  // Create a line
  _curve = new THREE.Line (geometry, material);

  scene.add(_curve);
}

// Create a spline
function createSplineCurve() {
  // smooth my curve over this many points
  var numPoints = 100;
  var spline = new THREE.SplineCurve3([
     new THREE.Vector3(0, 0, 0),
     new THREE.Vector3(0, 200, 0),
     new THREE.Vector3(150, 150, 0),
     new THREE.Vector3(150, 50, 0),
     new THREE.Vector3(250, 100, 0),
     new THREE.Vector3(250, 300, 0)
  ]);

  var material = new THREE.LineBasicMaterial({ color: 0x00ff00 });

  var geometry = new THREE.Geometry();
  var splinePoints = spline.getPoints(numPoints);

  for(var i = 0; i < splinePoints.length; i++){
      geometry.vertices.push(splinePoints[i]);
  }

  // Create the final object to add to the scene
  _curve = new THREE.Line (geometry, material);
  _curve.position.z = -350;
  _curve.position.x = 200;

  scene.add(_curve);
}


// Animate the scene
function render(time) {
    // Render the scene
    renderScene(time);

    // This function calls itself on every frame. You can for example change
    // the objects rotation on every call to create a turntable animation.
    requestAnimationFrame( render );
}

// var clock = new THREE.Clock();
function renderScene(time) {
  // time *= 0.001;
  //
  // cubes.forEach((cube, ndx) => {
  //   const speed = .2 + ndx * .1;
  //   const rot = time * speed;
  //   cube.rotation.x = rot;
  //   cube.rotation.y = rot;
  // });

	renderer.render( scene, camera );
};

// Runs each time the DOM window resize event fires.
// Resets the canvas dimensions to match window,
// then draws the new borders accordingly.
function resizeRendererToDisplaySize() {
    // Check if the canvas is not the same size.
    var elmtDiv = document.getElementById('WebGLCanvas'); // img with id
    if(elmtDiv)
    {
    	canvas = elmtDiv;
    	canvas.height = elmtDiv.clientHeight;
    	canvas.width = elmtDiv.clientWidth;
    }
    if(camera != null)
    {
        camera.aspect = canvas.width / canvas.height;
        camera.updateProjectionMatrix();
    }
    if(renderer != null)
        renderer.setSize( canvas.width, canvas.height );
}
